@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADICONSOLE_METATYPES_H
-#define AKONADICONSOLE_METATYPES_H
+#pragma once
 
 #include <akonadi/private/notificationmessagev2_p.h>
 
@@ -14,4 +13,3 @@
 Q_DECLARE_METATYPE(QList<QByteArray>)
 Q_DECLARE_METATYPE(QList<long long>)
 
-#endif
